Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/ActionShapeImpl.java')
-rw-r--r--extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/ActionShapeImpl.java114
1 files changed, 84 insertions, 30 deletions
diff --git a/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/ActionShapeImpl.java b/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/ActionShapeImpl.java
index 503e7f7772c..6fbd229af14 100644
--- a/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/ActionShapeImpl.java
+++ b/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/ActionShapeImpl.java
@@ -24,9 +24,11 @@ import org.eclipse.emf.ecore.util.EObjectContainmentWithInverseEList;
import org.eclipse.emf.ecore.util.InternalEList;
import org.eclipse.papyrus.umldi.ActionShape;
+import org.eclipse.papyrus.umldi.ConstraintLabel;
import org.eclipse.papyrus.umldi.PinShape;
import org.eclipse.papyrus.umldi.UMLDIPackage;
import org.eclipse.papyrus.umldi.UmlDiagramElement;
+
import org.eclipse.uml2.common.util.DerivedUnionEObjectEList;
/**
@@ -37,17 +39,20 @@ import org.eclipse.uml2.common.util.DerivedUnionEObjectEList;
* The following features are implemented:
* </p>
* <ul>
* <li>{@link org.eclipse.papyrus.umldi.impl.ActionShapeImpl#getOwnedUmlDiagramElement <em>Owned Uml Diagram Element</em>}</li>
* <li>{@link org.eclipse.papyrus.umldi.impl.ActionShapeImpl#getPinShape <em>Pin Shape</em>}</li>
* </ul>
*
* @generated
*/
public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShape {
+
/**
* The cached value of the '{@link #getPinShape() <em>Pin Shape</em>}' containment reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @see #getPinShape()
* @generated
* @ordered
@@ -55,8 +60,20 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
protected EList<PinShape> pinShape;
/**
+ * The cached value of the '{@link #getConditionLabel() <em>Condition Label</em>}' containment reference list.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ *
+ * @see #getConditionLabel()
+ * @generated
+ * @ordered
+ */
+ protected EList<ConstraintLabel> conditionLabel;
+
+ /**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
protected ActionShapeImpl() {
@@ -66,6 +83,7 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
@@ -76,6 +94,7 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
@@ -87,19 +106,21 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
* The array of subset feature identifiers for the '{@link #getOwnedUmlDiagramElement() <em>Owned Uml Diagram Element</em>}' reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @see #getOwnedUmlDiagramElement()
* @generated
* @ordered
*/
- protected static final int[] OWNED_UML_DIAGRAM_ELEMENT_ESUBSETS = new int[] {UMLDIPackage.ACTION_SHAPE__MAIN_LABEL, UMLDIPackage.ACTION_SHAPE__PIN_SHAPE};
+ protected static final int[] OWNED_UML_DIAGRAM_ELEMENT_ESUBSETS = new int[]{ UMLDIPackage.ACTION_SHAPE__STEREOTYPE_LABEL, UMLDIPackage.ACTION_SHAPE__MAIN_LABEL, UMLDIPackage.ACTION_SHAPE__STEREOTYPE_COMPARTMENT, UMLDIPackage.ACTION_SHAPE__PIN_SHAPE, UMLDIPackage.ACTION_SHAPE__CONDITION_LABEL };
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
public EList<PinShape> getPinShape() {
- if (pinShape == null) {
+ if(pinShape == null) {
pinShape = new EObjectContainmentWithInverseEList<PinShape>(PinShape.class, this, UMLDIPackage.ACTION_SHAPE__PIN_SHAPE, UMLDIPackage.PIN_SHAPE__ACTION_SHAPE);
}
return pinShape;
@@ -108,14 +129,30 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
+ * @generated
+ */
+ public EList<ConstraintLabel> getConditionLabel() {
+ if(conditionLabel == null) {
+ conditionLabel = new EObjectContainmentWithInverseEList<ConstraintLabel>(ConstraintLabel.class, this, UMLDIPackage.ACTION_SHAPE__CONDITION_LABEL, UMLDIPackage.CONSTRAINT_LABEL__ACTION_SHAPE);
+ }
+ return conditionLabel;
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ *
* @generated
*/
@SuppressWarnings("unchecked")
@Override
public NotificationChain eInverseAdd(InternalEObject otherEnd, int featureID, NotificationChain msgs) {
- switch (featureID) {
- case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
- return ((InternalEList<InternalEObject>)(InternalEList<?>)getPinShape()).basicAdd(otherEnd, msgs);
+ switch(featureID) {
+ case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
+ return ((InternalEList<InternalEObject>)(InternalEList<?>)getPinShape()).basicAdd(otherEnd, msgs);
+ case UMLDIPackage.ACTION_SHAPE__CONDITION_LABEL:
+ return ((InternalEList<InternalEObject>)(InternalEList<?>)getConditionLabel()).basicAdd(otherEnd, msgs);
}
return super.eInverseAdd(otherEnd, featureID, msgs);
}
@@ -123,13 +160,16 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public NotificationChain eInverseRemove(InternalEObject otherEnd, int featureID, NotificationChain msgs) {
- switch (featureID) {
- case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
- return ((InternalEList<?>)getPinShape()).basicRemove(otherEnd, msgs);
+ switch(featureID) {
+ case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
+ return ((InternalEList<?>)getPinShape()).basicRemove(otherEnd, msgs);
+ case UMLDIPackage.ACTION_SHAPE__CONDITION_LABEL:
+ return ((InternalEList<?>)getConditionLabel()).basicRemove(otherEnd, msgs);
}
return super.eInverseRemove(otherEnd, featureID, msgs);
}
@@ -137,13 +177,16 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public Object eGet(int featureID, boolean resolve, boolean coreType) {
- switch (featureID) {
- case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
- return getPinShape();
+ switch(featureID) {
+ case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
+ return getPinShape();
+ case UMLDIPackage.ACTION_SHAPE__CONDITION_LABEL:
+ return getConditionLabel();
}
return super.eGet(featureID, resolve, coreType);
}
@@ -151,16 +194,21 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@SuppressWarnings("unchecked")
@Override
public void eSet(int featureID, Object newValue) {
- switch (featureID) {
- case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
- getPinShape().clear();
- getPinShape().addAll((Collection<? extends PinShape>)newValue);
- return;
+ switch(featureID) {
+ case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
+ getPinShape().clear();
+ getPinShape().addAll((Collection<? extends PinShape>)newValue);
+ return;
+ case UMLDIPackage.ACTION_SHAPE__CONDITION_LABEL:
+ getConditionLabel().clear();
+ getConditionLabel().addAll((Collection<? extends ConstraintLabel>)newValue);
+ return;
}
super.eSet(featureID, newValue);
}
@@ -168,14 +216,18 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public void eUnset(int featureID) {
- switch (featureID) {
- case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
- getPinShape().clear();
- return;
+ switch(featureID) {
+ case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
+ getPinShape().clear();
+ return;
+ case UMLDIPackage.ACTION_SHAPE__CONDITION_LABEL:
+ getConditionLabel().clear();
+ return;
}
super.eUnset(featureID);
}
@@ -183,15 +235,18 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public boolean eIsSet(int featureID) {
- switch (featureID) {
- case UMLDIPackage.ACTION_SHAPE__OWNED_UML_DIAGRAM_ELEMENT:
- return isSetOwnedUmlDiagramElement();
- case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
- return pinShape != null && !pinShape.isEmpty();
+ switch(featureID) {
+ case UMLDIPackage.ACTION_SHAPE__OWNED_UML_DIAGRAM_ELEMENT:
+ return isSetOwnedUmlDiagramElement();
+ case UMLDIPackage.ACTION_SHAPE__PIN_SHAPE:
+ return pinShape != null && !pinShape.isEmpty();
+ case UMLDIPackage.ACTION_SHAPE__CONDITION_LABEL:
+ return conditionLabel != null && !conditionLabel.isEmpty();
}
return super.eIsSet(featureID);
}
@@ -199,12 +254,11 @@ public class ActionShapeImpl extends ActivityNodeShapeImpl implements ActionShap
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public boolean isSetOwnedUmlDiagramElement() {
- return super.isSetOwnedUmlDiagramElement()
- || eIsSet(UMLDIPackage.ACTION_SHAPE__PIN_SHAPE);
+ return super.isSetOwnedUmlDiagramElement() || eIsSet(UMLDIPackage.ACTION_SHAPE__PIN_SHAPE) || eIsSet(UMLDIPackage.ACTION_SHAPE__CONDITION_LABEL);
}
-
} //ActionShapeImpl

Back to the top
@@ -37,17 +39,20 @@ import org.eclipse.uml2.common.util.DerivedUnionEObjectEList;
* </p>
* <ul>
- * <li>{@link org.eclipse.papyrus.umldi.impl.ActionShapeImpl#getOwnedUmlDiagramElement <em>Owned Uml Diagram Element</em>}</li>
- * <li>{@link org.eclipse.papyrus.umldi.impl.ActionShapeImpl#getPinShape <em>Pin Shape</em>}</li>
+ * <li>{@link org.eclipse.papyrus.umldi.impl.ActionShapeImpl#getOwnedUmlDiagramElement <em>Owned Uml Diagram Element</em>}</li>
+ * <li>{@link org.eclipse.papyrus.umldi.impl.ActionShapeImpl#getPinShape <em>Pin Shape</em>}</li>
+ * <li>{@link org.eclipse.papyrus.umldi.impl.ActionShapeImpl#getConditionLabel <em>Condition Label</em>}</li>
* </ul>
*